#
# spec file for package kubeshark-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name kubeshark

Name:           kubeshark-cli
Version:        52.3.84
Release:        1.1
Summary:        CLI for the API traffic analyzer for Kubernetes
License:        Apache-2.0
URL:            https://github.com/kubeshark/kubeshark
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Kubeshark is an API Traffic Analyzer for Kubernetes providing real-time,
protocol-level visibility into Kubernetes’ internal network, capturing and
monitoring all traffic and payloads going in, out and across containers, pods,
nodes and clusters.

This package contains the kubeshark CLI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/kubeshark/kubeshark/misc.GitCommitHash=${COMMIT_HASH} \
   -X github.com/kubeshark/kubeshark/misc.Branch=main \
   -X github.com/kubeshark/kubeshark/misc.Platform=linux \
   -X github.com/kubeshark/kubeshark/misc.Ver=v%{version} \
   -X github.com/kubeshark/kubeshark/misc.BuildTimestamp=${BUILD_DATE}" \
   -o bin/%{executable_name} kubeshark.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.84:
  * added timestamp>now() as a global filter
  * set `disableTlsLog` to `true` by default.
  * Hub default limit set to 5GB (an arbitrary number)
  * show filter presets by default
  * change CPU limit to no limit Change memory limit to 3Gi
  * scripting-revamp-1 (#1630)
  * Prevent `hub` host-not-found nginx upstream error in `front`
    (#1628)
  * fix lint issue
  * Added log lines for verbosity
  * Added the scripting `console` command functionality to the
    `tap` command Added both the `scripting` and `console` commands
    to the `proxy` command Added a `scripting.console`, a boolean
    value indicating whether the `console` functionality should be
    part of the `tap` and `proxy` commands
  * Improved the `console` command made it resilient to Websocket
    breaks and redeployment.
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.83:
  * :bookmark: Bump the Helm chart version to 52.3.83
  * :bookmark: Bump the Helm chart version to 72.3.83
  * Added some error and info log lines
  * Add `tap.presetFiltersChangingEnabled` helm value (#1627)
  * Set reasonable `pcapdump` defaults. Storage is now at 10%% of
    the Worker's allocated storage.
  * Tag Tracer as well as the other components upon a new release
  * Ensure `scripting` command watched only JS files
  * Feat pcapsaver (#1621)
  * emit tls item (#1625)
  * Update README with resource guard configuration (#1623)
  * Add resource guard flag (#1622)
  * Regenerate `values.yaml` and `complete.yaml`
  * Do not enable `-unixsocket` flag of worker if no tracer is
    running (#1619)
  * Fixed a bug in the `console` command, where the CLI couldn't
    connect to Hub as when the `url.URL` method was used, the Host
    included a path
  * Add list permissions for kubeshark service account (#1617)
  * Add `udp` to list of enabled dissectors (#1616)
  * Make the `scritps` command directly use the K8s API without
    requiring a connector to Hub (#1615)
  * Print instructions for running `kubectl port-forward` command
    in case of failure (#1614)
  * propagate host root to the tracer (#1613)
  * Fix `-staletimeout` worker command value (#1611)
  * Template the `-staletimeout` flag (#1610)
  * updated Grafana dahsboard
  * text change
  * text changes
* Mon Sep 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubeshark-cli: CLI for the API traffic analyzer for
  Kubernetes
